#
# spec file for package python-defcon
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
%define skip_python36 1
Name:           python-defcon
Version:        0.10.3
Release:        1.4
Summary:        A set of UFO based objects for use in font editing applications
License:        MIT
URL:            https://github.com/robotools/defcon
Source:         https://files.pythonhosted.org/packages/source/d/defcon/defcon-%{version}.zip
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-FontTools >= 4.10.2
# SECTION fonttools[ufo,unicode]
Requires:       python-fs >= 2.2
%if 0%{?python_version_nodots} < 39
Requires:       python-unicodedata2 >= 13.0.0
%endif
# /SECTION
Suggests:       python-fontPens >= 0.1.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module FontTools >= 4.10.2}
BuildRequires:  %{python_module fs >= 2.2}
BuildRequires:  %{python_module pytest >= 3.0.3}
BuildRequires:  %{python_module unicodedata2 >= 13.0.0 if %python-base < 3.9}
# /SECTION
%python_subpackages

%description
A set of UFO based objects optimized for use in font editing applications.

%prep
%setup -q -n defcon-%{version}
sed -i -e '1{\,^#!%{_bindir}/env python,d}' Lib/defcon/test/tools/test_unicodeTools.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license License.txt
%{python_sitelib}/defcon
%{python_sitelib}/defcon-%{version}*-info

%changelog
* Mon Sep 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.3:
  * Add in missing `_dirty`
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.10.2
  * Create a new glyphset from the provided reader by @typemytype in #409
* Tue Jul 19 2022 Dirk Müller <dmueller@suse.com>
- update to 0.10.1:
  * Python 3.10 support
  * Add glyphSet argument in _stampLayerInfoDataState
  * when guideline.name is set to None remove the name key
  * add eq and hash to FuzzyNumber
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * drop python 3.6 support
* Thu Dec 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.9.0
  * Makes glyph.image object “sticky”, just like lib objects (#352)
  * Adds a .tempLib to font, layer, and glyph that is available for
    the life of the object and is never saved with the ufo. (#367)
- Skip python36: FontTools now dropped it.
* Tue Mar 23 2021 Benjamin Greiner <code@bnavigator.de>
- reinstate python36 build (python36-FontTools is available)
* Fri Mar 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update 0.8.1:
  * Fixes behavior with None in removeObserver (#349)
  * Resets glyph set on save (#297)
  * Gives Anchors and Guidelines a glyph attribute (#325)
  * Dispatcher enhancements (#337)
  * Adds __eq__ in BaseDict (#344)
* Sat Feb 13 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 (needs FontTools which needs scipy)
* Mon Jun 15 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.2:
  * Name the wheel file as non-universal (py3-only).
  * [setup.py] Mark library as requiring Python 3.6+, or else pip2 will attempt to install it on Python 2.7, which is no longer supported (#293).
  * Dropped support for Py2, now only Py3
  * Updated documentation: #232
  * Fixed docstring typos (thanks @Space0726!): #263
  * added notification: Font.GuidelineWillBeAdded: #239
  * Fixes for UFOZ (#209 testForExternalChanges and #218 glyphSet is required): #220
  * Added close to font: #269
  * Setting glyph.unicode will now set glyph.unicodes to a one member list: #258
  * Add notifications for: Glyph.LeftMarginWillChange, Glyph.LeftMarginDidChange, Glyph.RightMarginWillChange, Glyph.RightMarginDidChange, Glyph.TopMarginWillChange, Glyph.TopMarginDidChange, Glyph.BottomMarginWillChange, Glyph.BottomMarginDidChange: #253
  * Improved joinSegments: #259
  * Added identifier to addComponent callback: #268
  * Fix glyphs with components getting proper area value: #272
  * Use ufoFormatTuple: #289
  * Add ufoFormatVersionTuple property, deprecate ufoFormatVersion: #291
* Tue May 26 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix FontTool dep (camelcase)
- Remove devel dependency
* Wed May 20 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-defcon
